@@ -50,7 +50,7 @@
 #include "vtkVoxel.h"
 #include "vtkWedge.h"
 
-vtkCxxRevisionMacro(vtkUnstructuredGrid, "$Revision: 1.8.6.1 $");
+vtkCxxRevisionMacro(vtkUnstructuredGrid, "$Revision: 1.8.6.2 $");
 vtkStandardNewMacro(vtkUnstructuredGrid);
 
 vtkUnstructuredGrid::vtkUnstructuredGrid ()
@@ -867,6 +867,12 @@ void vtkUnstructuredGrid::SetCells(vtkUnsignedCharArray *cellTypes,
 //----------------------------------------------------------------------------
 void vtkUnstructuredGrid::BuildLinks()
 {
+  // Remove the old links if they are already built
+  if (this->Links)
+    {
+    this->Links->UnRegister(this);
+    }
+
   this->Links = vtkCellLinks::New();
   this->Links->Allocate(this->GetNumberOfPoints());
   this->Links->Register(this);
@@ -1168,14 +1174,6 @@ void vtkUnstructuredGrid::DeepCopy(vtkDataObject *dataObject)
       this->Links->UnRegister(this);
       this->Links = NULL;
       }
-    if (grid->Links)
-      {
-      this->Links = vtkCellLinks::New();
-      this->Links->DeepCopy(grid->Links);
-      this->Links->Register(this);
-      this->Links->Delete();
-      }
-
     if ( this->Types )
       {
       this->Types->UnRegister(this);
@@ -1205,6 +1203,14 @@ void vtkUnstructuredGrid::DeepCopy(vtkDataObject *dataObject)
 
   // Do superclass
   this->vtkPointSet::DeepCopy(dataObject);
+
+  // Finally Build Links if we need to
+  if (grid && grid->Links)
+    {
+    this->BuildLinks();
+    }
+
+
 }
 
 
