@@ -3,8 +3,8 @@
   Program:   DICOMParser
   Module:    $RCSfile: DICOMAppHelper.h,v $
   Language:  C++
-  Date:      $Date: 2004/02/25 17:27:22 $
-  Version:   $Revision: 1.12 $
+  Date:      $Date: 2006/08/31 17:30:29 $
+  Version:   $Revision: 1.12.20.1 $
 
   Copyright (c) 2003 Matt Turek
   All rights reserved.
@@ -288,7 +288,14 @@ public:
     {
       return this->ImagePositionPatient;
     }
-  
+
+  /** Get the (DICOM) directions cosines. It consist of the components
+   * of the first two vectors. The third vector needs to be computed
+   * to form an orthonormal basis. */
+ float *GetImageOrientationPatient()
+    {
+      return this->ImageOrientationPatient;
+    }
   
   /** Get the number of bits allocated per pixel of the last image
    *  processed by the DICOMParser */
@@ -470,6 +477,7 @@ public:
   int SliceNumber; 
   int Dimensions[2];
   float ImagePositionPatient[3];
+  float ImageOrientationPatient[6];
 
   // map from series UID to vector of files in the series 
   // dicom_stl::map<dicom_stl::string, dicom_stl::vector<dicom_stl::string>, ltstdstr> SeriesUIDMap;
