@@ -1,16 +1,16 @@
 /*
  * tkPort.h --
  *
- *      This header file handles porting issues that occur because of
- *      differences between systems.  It reads in platform specific
- *      portability files.
+ *  This header file handles porting issues that occur because of
+ *  differences between systems.  It reads in platform specific
+ *  portability files.
  *
  * Copyright (c) 1995 Sun Microsystems, Inc.
  *
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * RCS: @(#) $Id: tkPort.h,v 1.1 2004/01/07 22:32:38 barre Exp $
+ * RCS: @(#) $Id: tkPort.h,v 1.1 2004/01/07 22:32:39 barre Exp $
  */
 
 #ifndef _TKPORT
@@ -27,9 +27,11 @@
 #   include "tkWinPort.h"
 #else
 #   if defined(MAC_TCL)
-#       include "tkMacPort.h"
+#  include "tkMacPort.h"
+#   elif defined(MAC_OSX_TK)
+#  include "tkMacOSXPort.h"
 #   else
-#       include "../unix/tkUnixPort.h"
+#  include "tkUnixPort.h"
 #   endif
 #endif
 
